#
# spec file for package syslog-ng
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         __provides_exclude_from ^%{_libdir}/syslog-ng/
%define         syslog_ng_sockets_cfg	%{syslog_ng_rundir}/additional-log-sockets.conf
%global		py_ver	 %(rpm -qf %{_bindir}/python3 --qf "%%{version}" | awk -F. '{print $1"."$2}')

#redis only in openSUSE
%if !0%{?is_opensuse}
%bcond_with	redis
%else
%bcond_without	redis
%endif

# mqtt only in Tumbleweed
%if 0%{?suse_version} > 1500
%bcond_without	mqtt
%else
%bcond_with	mqtt
%endif

# GRPC and BPF dependencies only in TW
%if 0%{?suse_version} > 1500
%bcond_without  grpc
%bcond_without	bpf
%else
%bcond_with     grpc
%bcond_with	bpf
%endif

# CloudAuth needs 15+
%if 0%{?suse_version} >= 1500
%bcond_without  cloudauth
%else
%bcond_with     cloudauth
%endif

%if %{with grpc}
BuildRequires:  grpc-devel
BuildRequires:  protobuf-devel
%endif

# missing dependencies on SLES 15
%if 0%{?sle_version} >= 150000 && !0%{?is_opensuse}
%bcond_with	dbi
%bcond_with	java
%bcond_with	geoip
%else
%bcond_without  dbi
%ifarch armv7l armv7hl
%bcond_with	java
%else
%bcond_without	java
%endif
%bcond_without	geoip
%endif
#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir %{_localstatedir}/adm/fillup-templates
%endif
%if %{defined _rundir}
%define         syslog_ng_rundir        %{_rundir}/syslog-ng
%else
%define         syslog_ng_rundir	%{_localstatedir}/run/syslog-ng
%endif
# turn features on and off
%bcond_without	python
%bcond_without	curl
%bcond_without	smtp
# mongodb & amqp C clients are no more bundled with syslog-ng sources
# and not yet available in openSUSE
# leaving here for future usage
%bcond_with	mongodb
%bcond_with	amqp
Name:           syslog-ng
Version:        4.6.0
Release:        3.6
Summary:        Enhanced system logging daemon
License:        GPL-2.0-only
Group:          System/Daemons
URL:            https://syslog-ng.org/
Source0:        https://github.com/balabit/syslog-ng/releases/download/syslog-ng-%{version}/%{name}-%{version}.tar.gz
Source1:        syslog-ng.sysconfig
Source2:        syslog-ng.conf.default
Source3:        syslog-ng.service
Source4:        syslog-ng-service-prepare
BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  gcc-c++
BuildRequires:  glib2-devel
BuildRequires:  libcap-devel
BuildRequires:  libjson-devel
BuildRequires:  libnet-devel
BuildRequires:  libopenssl-devel
BuildRequires:  libtool
BuildRequires:  net-snmp-devel
BuildRequires:  pcre2-devel
BuildRequires:  pkgconfig
BuildRequires:  python3
BuildRequires:  tcpd-devel
BuildRequires:  pkgconfig(libsystemd)
#!BuildIgnore:  rsyslog
Requires(pre):  %fillup_prereq
Requires(pre):  syslog-service >= 2.0
Conflicts:      syslog
Provides:       syslog
Provides:       sysvinit(syslog)
%if %{with mqtt}
BuildRequires:  libpaho-mqtt-devel
%endif
%if %{with smtp}
BuildRequires:  libesmtp-devel
%endif
%if %{with curl}
BuildRequires:  libcurl-devel
%endif
%if %{with geoip}
%if 0%{?leap_version} >= 420200
BuildRequires:  libmaxminddb-devel
%endif
%if 0%{?suse_version} > 1320
BuildRequires:  libmaxminddb-devel
%endif
%endif
%if %{with redis}
BuildRequires:  hiredis-devel
%endif
%if %{with dbi}
BuildRequires:  libdbi-devel
%endif
%if %{with java}
BuildRequires:  java-devel >= 1.8
%endif
%if %{with python}
BuildRequires:  python3-PyYAML
BuildRequires:  python3-cachetools
BuildRequires:  python3-certifi
BuildRequires:  python3-charset-normalizer
BuildRequires:  python3-devel
BuildRequires:  python3-google-auth
BuildRequires:  python3-idna
BuildRequires:  python3-kubernetes
BuildRequires:  python3-oauthlib
BuildRequires:  python3-pip
BuildRequires:  python3-pyasn1
BuildRequires:  python3-pyasn1-modules
BuildRequires:  python3-python-dateutil
BuildRequires:  python3-requests
BuildRequires:  python3-requests-oauthlib
BuildRequires:  python3-rsa
BuildRequires:  python3-setuptools
BuildRequires:  python3-six
BuildRequires:  python3-urllib3
BuildRequires:  python3-websocket-client
%endif

%if %{with bpf}
BuildRequires:  bpftool
BuildRequires:  clang13
BuildRequires:  libbpf-devel
%endif

%description
syslog-ng is an enhanced log daemon, supporting a wide range of input and
output methods: syslog, unstructured text, message queues, databases (SQL
and NoSQL alike) and more.

Key features:

 * receive and send RFC3164 and RFC5424 style syslog messages
 * work with any kind of unstructured data
 * receive and send JSON formatted messages
 * classify and structure logs with builtin parsers (csv-parser(),
   db-parser(), ...)
 * normalize, crunch and process logs as they flow through the system
 * hand on messages for further processing using message queues (like
   AMQP), files or databases (like PostgreSQL or MongoDB).

%package -n libevtlog-4_6-0
Summary:        Syslog-ng event logger library runtime
Group:          System/Libraries

%description -n libevtlog-4_6-0
The EventLog library provides an alternative to the simple syslog()
API provided on UNIX systems. Compared to syslog, EventLog adds
structured messages.

EventLog provides an interface to build, format and output an event
record. The exact format and output method can be customized by the
administrator via a configuration file.

This package is now merged into syslog-ng.

%package curl
Summary:        HTTP destination support for syslog-ng
Group:          System/Daemons
Requires:       %{name} = %{version}

%description curl
This package provides HTTP destination support for syslog-ng by means
of libcurl.

%package java
Summary:        Java destination support for syslog-ng
Group:          System/Daemons
Requires:       %{name} = %{version}

%description java
This package provides Java destination support for syslog-ng.

%package sql
Summary:        SQL support using DBI for syslog-ng
Group:          System/Daemons
Requires:       %{name} = %{version}

%description sql
This package provides the libafsql module providing support for
logging into a SQL database using DBI.

%package smtp
Summary:        SMTP output support for syslog-ng
Group:          System/Daemons
Requires:       %{name} = %{version}

%description smtp
This package provides the afsmtp module providing support for
logging into SMTP.

%package geoip
Summary:        GeoIP (MaxMindDB) support for syslog-ng
Group:          System/Daemons
Requires:       %{name} = %{version}

%description geoip
This package provides GeoIP (MaxMindDB) modules providing support for
logging geo-location information.

%package redis
Summary:        Redis destination support for syslog-ng
Group:          System/Daemons
Requires:       %{name} = %{version}

%description redis
This package provides the libredis module providing support for
logging to a redis destination.

%package bpf
Summary:        Faster UDP log collection for syslog-ng
Group:          System/Daemons
Requires:       %{name} = %{version}

%description bpf
This package provides faster UDP log collection for syslog-ng using bpf

%package python
Summary:        Python destination support for syslog-ng
Group:          System/Daemons
Requires:       %{name} = %{version}

%description python
This package provides Python destination support for syslog-ng.

%package python-modules
Summary:        Python modules for syslog-ng
Group:          System/Daemons
Requires:       %{name} = %{version}
Requires:       %{name}-python
Requires:       python3-PyYAML
Requires:       python3-cachetools
Requires:       python3-certifi
Requires:       python3-charset-normalizer
Requires:       python3-google-auth
Requires:       python3-idna
Requires:       python3-kubernetes
Requires:       python3-pip
Requires:       python3-pyasn1
Requires:       python3-pyasn1-modules
Requires:       python3-python-dateutil
Requires:       python3-requests
Requires:       python3-rsa
Requires:       python3-six
Requires:       python3-websocket-client

%description python-modules
This package provides python modules for syslog-ng, for
Kubernetes log enrichment, Hypr support, etc.

%package devel
Summary:        Development files for syslog-ng
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Provides:       libevtlog-devel = 0.2.13
Obsoletes:      libevtlog-devel <= 0.2.13
Requires:       glib2-devel
Requires:       glibc-devel
Requires:       libcap-devel
Requires:       libopenssl-devel
Requires:       pcre-devel
Requires:       systemd-devel

%description devel
This package provides files necessary for syslog-ng development.

%package snmp
Summary:        SNMP support for syslog-ng
Group:          System/Daemons
Requires:       %{name} = %{version}

%description snmp
This package provides SNMP support for syslog-ng

%package mqtt
Summary:        MQTT support for syslog-ng
Group:          System/Daemons
Requires:       %{name} = %{version}

%package grpc
Summary:        Common files for grpc-based syslog-ng drivers
Group:          System/Daemons
Requires:       %{name} = %{version}

%description grpc
This package provides provides common files for grpc-based syslog-ng drivers

%package opentelemetry
Summary:        OpenTelemetry support for syslog-ng
Group:          System/Daemons
Requires:       %{name} = %{version}
Requires:       %{name}-grpc

%description opentelemetry
This package provides OpenTelemetry support for syslog-ng

%package loki
Summary:        Loki destination support for syslog-ng
Group:          System/Daemons
Requires:       %{name} = %{version}
Requires:       %{name}-grpc

%description loki
This package provides Loki destination support for syslog-ng

%package bigquery
Summary:        Google BigQuery destination support for syslog-ng
Group:          System/Daemons
Requires:       %{name} = %{version}
Requires:       %{name}-grpc

%description bigquery
This package provides Google BigQuery destination support for syslog-ng

%package cloudauth
Summary:        Cloud Authentication support for syslog-ng: pubsub
Group:          System/Daemons
Requires:       %{name} = %{version}

%description cloudauth
This package provides Cloud Authentication support for syslog-ng,
currently used for Google PubSub

%description mqtt
This package provides MQTT support for syslog-ng

%prep
%setup -q -n syslog-ng-%{version}
# fill out placeholders in the config,
# systemd service and prepare script.
for file in \
	syslog-ng.conf.default \
	syslog-ng.service \
	syslog-ng-service-prepare \
; do
	sed \
	-e 's;@sbindir@;%{_sbindir};g' \
	-e 's;RUN_DIR;%{syslog_ng_rundir};g' \
	-e 's;ADDITIONAL_SOCKETS;%{syslog_ng_sockets_cfg};g' \
	"%{_sourcedir}/${file}" > "${file}"
done
%ifarch s390 s390x
    sed -i -e 's/tty10/console/g' syslog-ng.conf.default
%endif

# fix python
# sed -i 's|^#\s*!%{_bindir}/env python|#!%{_bindir}/python3|' lib/merge-grammar.py
# touch -r lib/cfg-grammar.y lib/merge-grammar.py

%build
#autoreconf -fi
##
## build ####################################################
##
export CFLAGS="%{optflags}"

export AM_YFLAGS=-d

export BPFTOOL=/usr/sbin/bpftool

%configure \
	--prefix=%{_prefix}			\
	--enable-ipv6				\
	--enable-manpages			\
	--enable-tcp-wrapper			\
	--enable-spoof-source			\
	--sysconfdir=%{_sysconfdir}/syslog-ng		\
	--localstatedir=%{_localstatedir}/lib/syslog-ng	\
	--with-pidfile-dir=%{_localstatedir}/run	\
	--with-module-dir="%{_libdir}/syslog-ng"	\
	--with-default-modules="affile,afprog,afsocket,afuser,basicfuncs,csvparser,dbparser,syslogformat"	\
	--datadir="%{_datadir}"	\
	--without-compile-date			\
	--enable-ssl				\
%if %{with grpc}
        --enable-cpp                            \
        --enable-grpc                           \
%endif
%if %{with cloudauth}
        --enable-cloud-auth                     \
%else
        --disable-cloud-auth                    \
%endif
        --enable-afsnmp                         \
%if %{with bpf}
        --enable-ebpf                           \
%endif
	--disable-native			\
%if %{with mqtt}
	--enable-mqtt				\
%endif
%if %{with smtp}
        --with-libesmtp=%{_prefix}/lib                \
%endif
	--enable-systemd			\
	--with-systemd-journal=system		\
%if %{with dbi}
	--enable-sql				\
%endif
        --enable-json                           \
	--enable-capabilities			\
%if %{with amqp}
        --enable-amqp                        \
%else
        --disable-amqp                       \
%endif
%if %{with mongodb}
        --enable-mongodb                        \
%else
        --disable-mongodb                       \
%endif
%if %{with redis}
	--enable-redis				\
%endif
%if %{with java}
       --enable-java                           \
%else
       --disable-java                          \
%endif
       --disable-java-modules                  \
%if %{with python}
	--enable-python				\
	--with-python=%{py_ver}			\
        --with-python-packages=none           \
%else
	--disable-python			\
%endif
        --enable-dynamic-linking

#
# - build syslog-ng
#
%make_build

%install
##
## install ##################################################
##
for dir in /sbin \
           %{_sysconfdir}/syslog-ng \
           %{_localstatedir}/lib/syslog-ng \
           %{_localstatedir}/run/syslog-ng \
%if 0%{?suse_version} >= 1500
           %{_fillupdir} ;
%else
           %{_localstatedir}/adm/fillup-templates ;
%endif
do
	test -d %{buildroot}/${dir} || \
	install -d -m755 %{buildroot}/${dir}
done
#
%make_install
#
install -d -m755 %{buildroot}%{_unitdir}/
install -c -m644 syslog-ng.service         %{buildroot}%{_unitdir}/
install -c -m755 syslog-ng-service-prepare %{buildroot}%{_sbindir}/

# install config.h (bnc#982487)
install -p -m644 config.h %{buildroot}%{_includedir}/%{name}

# install configs
install -m644 syslog-ng.conf.default \
              %{buildroot}/%{_sysconfdir}/syslog-ng/syslog-ng.conf
install -m644 %{_sourcedir}/syslog-ng.sysconfig \
              %{buildroot}/%{_fillupdir}/sysconfig.syslog-ng
# create empty /etc/syslog-ng/conf.d/
install -d -m755 %{buildroot}%{_sysconfdir}/syslog-ng/conf.d/

%if 0%{?suse_version} < 1550
# create a compatibility link in /sbin
ln -sf %{_sbindir}/syslog-ng %{buildroot}/sbin/
%endif

# don't package update-patterndb now
rm %{buildroot}%{_bindir}/update-patterndb

# delete java destination related files
rm -fr %{buildroot}%{_datadir}/syslog-ng/include/scl/elasticsearch/plugin.conf
rm -fr %{buildroot}%{_datadir}/syslog-ng/include/scl/elasticsearch/elastic-java.conf
rm -fr %{buildroot}%{_datadir}/syslog-ng/include/scl/hdfs/
rm -fr %{buildroot}%{_datadir}/syslog-ng/include/scl/kafka/

# create ghosts
install -d -m755 %{buildroot}%{syslog_ng_rundir}
touch            %{buildroot}%{syslog_ng_sockets_cfg}
chmod 644        %{buildroot}%{syslog_ng_sockets_cfg}

%pre
%{service_add_pre syslog-ng.service}

%post
##
## post install #############################################
##
/sbin/ldconfig
#
# remove obsolete variables
#
%{remove_and_set -n syslog SYSLOG_DAEMON SYSLOG_REQUIRES_NETWORK}
#
# add SYSLOG_NG_* variables if needed
#
%{fillup_only -ans syslog ng}
#
# create dirs, touch log default files
#
mkdir -p var/log
touch var/log/messages;  chmod 640 var/log/messages
touch var/log/mail;      chmod 640 var/log/mail
touch var/log/mail.info; chmod 640 var/log/mail.info
touch var/log/mail.warn; chmod 640 var/log/mail.warn
touch var/log/mail.err;  chmod 640 var/log/mail.err
#
# touch the additional log files we are using
#
touch var/log/acpid;            chmod 640 var/log/acpid
touch var/log/firewall;         chmod 640 var/log/firewall
touch var/log/NetworkManager;   chmod 640 var/log/NetworkManager
#
# generate empty additional-log-sockets.conf file
# see also syslog-ng.conf.default in pkg src dir.
#
additional_sockets="%{syslog_ng_sockets_cfg}"
install -d -m750 ${additional_sockets%/*}
cat >$additional_sockets <<EOF
source chroots { };
EOF
chmod 640 "${additional_sockets#/}"
#
# Enable the syslog-ng systemd service
#
# This macro enables based on a systemctl preset config file only
%{service_add_post syslog-ng.service}
# But we want to enable a syslog-daemon regardless of the preset;
# force the creation of a syslog.service alias link (bnc#790805).
# We do not check the obsolete SYSLOG_DAEMON variable as we want
# to switch when installing it and there is a provider conflict.
%{_bindir}/systemctl -f enable syslog-ng.service >/dev/null 2>&1 || :

%preun
##
## pre uninstall ############################################
##
%{service_del_preun syslog.socket}
%{service_del_preun syslog-ng.service}

%postun
##
## post uninstall ###########################################
##
#
# update linker caches
#
/sbin/ldconfig
#
# cleanup init scripts
#
%{service_del_postun syslog-ng.service}

%post -n libevtlog-4_6-0 -p /sbin/ldconfig
%postun -n libevtlog-4_6-0 -p /sbin/ldconfig

%files
##
## file list ################################################
##
%license COPYING
%doc AUTHORS NEWS.md
%doc syslog-ng.conf.default
%if 0%{?suse_version} < 1550
/sbin/syslog-ng
%endif
%attr(755,root,root) %{_sbindir}/syslog-ng
%attr(755,root,root) %{_sbindir}/syslog-ng-ctl
%attr(755,root,root) %{_sbindir}/syslog-ng-debun
%attr(755,root,root) %{_sbindir}/syslog-ng-service-prepare
%attr(755,root,root) %{_bindir}/loggen
%attr(755,root,root) %{_bindir}/pdbtool
%attr(755,root,root) %{_bindir}/dqtool
%attr(755,root,root) %{_bindir}/persist-tool
%attr(755,root,root) %{_bindir}/slogencrypt
%attr(755,root,root) %{_bindir}/slogkey
%attr(755,root,root) %{_bindir}/slogverify
%attr(755,root,root) %{_bindir}/syslog-ng-update-virtualenv
%{_mandir}/man5/syslog-ng.conf.5%{?ext_man}
%{_mandir}/man8/syslog-ng.8%{?ext_man}
%{_mandir}/man1/pdbtool.1%{?ext_man}
%{_mandir}/man1/loggen.1%{?ext_man}
%{_mandir}/man1/syslog-ng-ctl.1%{?ext_man}
%{_mandir}/man1/dqtool.1%{?ext_man}
%{_mandir}/man1/syslog-ng-debun.1%{?ext_man}
%{_mandir}/man1/persist-tool.1.gz
%{_mandir}/man1/slogencrypt.1*
%{_mandir}/man1/slogkey.1*
%{_mandir}/man1/slogverify.1*
%{_mandir}/man7/secure-logging.7*
%dir %{_libdir}/syslog-ng
%dir %{_libdir}/syslog-ng/loggen
%dir %{_datadir}/syslog-ng
%dir %{_datadir}/syslog-ng/include
%dir %{_datadir}/syslog-ng/include/scl
%dir %{_datadir}/syslog-ng/include/scl/graphite
%dir %{_datadir}/syslog-ng/include/scl/nodejs
%dir %{_datadir}/syslog-ng/include/scl/pacct
%dir %{_datadir}/syslog-ng/include/scl/rewrite
%dir %{_datadir}/syslog-ng/include/scl/syslogconf
%dir %{_datadir}/syslog-ng/include/scl/system
%dir %{_datadir}/syslog-ng/include/scl/solaris
%dir %{_datadir}/syslog-ng/include/scl/mbox/
%dir %{_datadir}/syslog-ng/include/scl/apache/
%dir %{_datadir}/syslog-ng/include/scl/loggly/
%dir %{_datadir}/syslog-ng/include/scl/logmatic/
%dir %{_datadir}/syslog-ng/include/scl/cisco/
%dir %{_datadir}/syslog-ng/include/scl/snmptrap/
%dir %{_datadir}/syslog-ng/include/scl/osquery/
%dir %{_datadir}/syslog-ng/include/scl/windowseventlog/
%dir %{_datadir}/syslog-ng/include/scl/loadbalancer/
%dir %{_datadir}/syslog-ng/include/scl/cim/
%dir %{_datadir}/syslog-ng/include/scl/default-network-drivers/
%dir %{_datadir}/syslog-ng/include/scl/ewmm/
%dir %{_datadir}/syslog-ng/include/scl/iptables/
%dir %{_datadir}/syslog-ng/include/scl/sudo/
%dir %{_datadir}/syslog-ng/include/scl/graylog2/
%dir %{_datadir}/syslog-ng/include/scl/linux-audit/
%dir %{_datadir}/syslog-ng/include/scl/websense/
%dir %{_datadir}/syslog-ng/include/scl/collectd/
%dir %{_datadir}/syslog-ng/include/scl/netskope/
%dir %{_datadir}/syslog-ng/include/scl/junos/
%dir %{_datadir}/syslog-ng/include/scl/checkpoint/
%dir %{_datadir}/syslog-ng/include/scl/paloalto/
%dir %{_datadir}/syslog-ng/include/scl/sumologic/
%dir %{_datadir}/syslog-ng/include/scl/cee/
%dir %{_datadir}/syslog-ng/include/scl/discord/
%dir %{_datadir}/syslog-ng/include/scl/fortigate/
%dir %{_datadir}/syslog-ng/include/scl/mariadb/
%dir %{_datadir}/syslog-ng/include/scl/python/
%dir %{_datadir}/syslog-ng/include/scl/splunk/
%dir %{_datadir}/syslog-ng/include/scl/logscale/
%dir %{_datadir}/syslog-ng/include/scl/opensearch/
%dir %{_datadir}/syslog-ng/include/scl/google/
%dir %{_datadir}/syslog-ng/include/scl/openobserve/
%dir %{_datadir}/syslog-ng/include/scl/pgsql/
%dir %{_datadir}/syslog-ng/include/scl/pihole/
%dir %{_datadir}/syslog-ng/include/scl/qbittorrent/
%dir %{_datadir}/syslog-ng/include/scl/darwinosl/
%dir %{_datadir}/syslog-ng/xsd
%dir %{_sysconfdir}/syslog-ng
%dir %{_sysconfdir}/syslog-ng/conf.d
%config(noreplace) %{_sysconfdir}/syslog-ng/syslog-ng.conf
%{_unitdir}/syslog-ng.service
%dir %{_localstatedir}/lib/syslog-ng
%attr(0755,root,root) %dir %ghost %{syslog_ng_rundir}
%attr(0644,root,root) %ghost %{syslog_ng_sockets_cfg}
%if 0%{?suse_version} >= 1500
%{_fillupdir}/sysconfig.syslog-ng
%else
%{_localstatedir}/adm/fillup-templates/sysconfig.syslog-ng
%endif
%{_libdir}/libsyslog-ng-*.so.*
%{_libdir}/libsecret-storage.so.*
%{_libdir}/libloggen_helper-*.so.*
%{_libdir}/libloggen_plugin-*.so.*
%attr(755,root,root) %{_libdir}/syslog-ng/libadd-contextual-data.so
%attr(755,root,root) %{_libdir}/syslog-ng/libsecure-logging.so
%if %{with amqp}
%attr(755,root,root) %{_libdir}/syslog-ng/libafamqp.so
%endif
%attr(755,root,root) %{_libdir}/syslog-ng/libaffile.so
%attr(755,root,root) %{_libdir}/syslog-ng/libafprog.so
%attr(755,root,root) %{_libdir}/syslog-ng/libappmodel.so
%if %{with mongodb}
%attr(755,root,root) %{_libdir}/syslog-ng/libafmongodb.so
%endif
%attr(755,root,root) %{_libdir}/syslog-ng/libafsocket.so
%attr(755,root,root) %{_libdir}/syslog-ng/libafstomp.so
%attr(755,root,root) %{_libdir}/syslog-ng/libafuser.so
%attr(755,root,root) %{_libdir}/syslog-ng/libbasicfuncs.so
%attr(755,root,root) %{_libdir}/syslog-ng/libconfgen.so
%attr(755,root,root) %{_libdir}/syslog-ng/libcsvparser.so
%attr(755,root,root) %{_libdir}/syslog-ng/libcryptofuncs.so
%attr(755,root,root) %{_libdir}/syslog-ng/libexamples.so
%attr(755,root,root) %{_libdir}/syslog-ng/libgraphite.so
%attr(755,root,root) %{_libdir}/syslog-ng/libjson-plugin.so
%attr(755,root,root) %{_libdir}/syslog-ng/libkvformat.so
%attr(755,root,root) %{_libdir}/syslog-ng/liblinux-kmsg-format.so
%attr(755,root,root) %{_libdir}/syslog-ng/libpseudofile.so
%attr(755,root,root) %{_libdir}/syslog-ng/libcef.so
%attr(755,root,root) %{_libdir}/syslog-ng/libtimestamp.so
%attr(755,root,root) %{_libdir}/syslog-ng/libdisk-buffer.so
%attr(755,root,root) %{_libdir}/syslog-ng/libtfgetent.so
%attr(755,root,root) %{_libdir}/syslog-ng/libmap-value-pairs.so
%attr(755,root,root) %{_libdir}/syslog-ng/libtags-parser.so
%attr(755,root,root) %{_libdir}/syslog-ng/libxml.so
%attr(755,root,root) %{_libdir}/syslog-ng/libsdjournal.so
%attr(755,root,root) %{_libdir}/syslog-ng/libsyslogformat.so
%attr(755,root,root) %{_libdir}/syslog-ng/libstardate.so
%attr(755,root,root) %{_libdir}/syslog-ng/libsystem-source.so
%attr(755,root,root) %{_libdir}/syslog-ng/libhook-commands.so
%attr(755,root,root) %{_libdir}/syslog-ng/loggen/libloggen_socket_plugin.so
%attr(755,root,root) %{_libdir}/syslog-ng/loggen/libloggen_ssl_plugin.so
%attr(755,root,root) %{_libdir}/syslog-ng/libazure-auth-header.so
%attr(755,root,root) %{_libdir}/syslog-ng/libregexp-parser.so
%attr(755,root,root) %{_libdir}/syslog-ng/librate-limit-filter.so
%attr(755,root,root) %{_libdir}/syslog-ng/libcorrelation.so
%attr(755,root,root) %{_libdir}/syslog-ng/libmetrics-probe.so
%attr(644,root,root) %{_datadir}/syslog-ng/include/scl/graphite/README
%attr(644,root,root) %{_datadir}/syslog-ng/include/scl/graphite/plugin.conf
%attr(644,root,root) %{_datadir}/syslog-ng/include/scl/nodejs/plugin.conf
%attr(644,root,root) %{_datadir}/syslog-ng/include/scl/pacct/plugin.conf
%attr(644,root,root) %{_datadir}/syslog-ng/include/scl/rewrite/cc-mask.conf
%attr(644,root,root) %{_datadir}/syslog-ng/include/scl/system/plugin.conf
%attr(644,root,root) %{_datadir}/syslog-ng/include/scl/syslogconf/README
%attr(755,root,root) %{_datadir}/syslog-ng/include/scl/syslogconf/convert-syslogconf.awk
%attr(644,root,root) %{_datadir}/syslog-ng/include/scl/syslogconf/plugin.conf
%attr(644,root,root) %{_datadir}/syslog-ng/include/scl/cim/template.conf
%attr(644,root,root) %{_datadir}/syslog-ng/include/scl/solaris/plugin.conf
%attr(644,root,root) %{_datadir}/syslog-ng/include/scl/mbox/mbox.conf
%attr(644,root,root) %{_datadir}/syslog-ng/include/scl/apache/apache.conf
%attr(644,root,root) %{_datadir}/syslog-ng/include/scl/loggly/loggly.conf
%attr(644,root,root) %{_datadir}/syslog-ng/include/scl/logmatic/logmatic.conf
%attr(644,root,root) %{_datadir}/syslog-ng/include/scl/cisco/plugin.conf
%attr(644,root,root) %{_datadir}/syslog-ng/include/scl/snmptrap/snmptrapd-source.conf
%attr(644,root,root) %{_datadir}/syslog-ng/include/scl/osquery/plugin.conf
%attr(644,root,root) %{_datadir}/syslog-ng/include/scl/windowseventlog/plugin.conf
%attr(644,root,root) %{_datadir}/syslog-ng/include/scl/windowseventlog/windowseventlog.xml
%attr(644,root,root) %{_datadir}/syslog-ng/include/scl/loadbalancer/gen-loadbalancer.sh
%attr(644,root,root) %{_datadir}/syslog-ng/include/scl/loadbalancer/plugin.conf
%attr(644,root,root) %{_datadir}/syslog-ng/include/scl/cim/adapter.conf
%attr(644,root,root) %{_datadir}/syslog-ng/include/scl/default-network-drivers/plugin.conf
%attr(644,root,root) %{_datadir}/syslog-ng/include/scl/ewmm/ewmm.conf
%attr(644,root,root) %{_datadir}/syslog-ng/include/scl/iptables/iptables.conf
%attr(644,root,root) %{_datadir}/syslog-ng/include/scl/sudo/sudo.conf
%attr(644,root,root) %{_datadir}/syslog-ng/include/scl/graylog2/plugin.conf
%attr(644,root,root) %{_datadir}/syslog-ng/include/scl/linux-audit/linux-audit.conf
%attr(644,root,root) %{_datadir}/syslog-ng/include/scl/websense/plugin.conf
%attr(644,root,root) %{_datadir}/syslog-ng/include/scl/collectd/plugin.conf
%attr(644,root,root) %{_datadir}/syslog-ng/include/scl/netskope/plugin.conf
%attr(644,root,root) %{_datadir}/syslog-ng/include/scl/junos/plugin.conf
%attr(644,root,root) %{_datadir}/syslog-ng/include/scl/checkpoint/plugin.conf
%attr(644,root,root) %{_datadir}/syslog-ng/include/scl/paloalto/panos.conf
%attr(644,root,root) %{_datadir}/syslog-ng/include/scl/sumologic/sumologic.conf
%attr(644,root,root) %{_datadir}/syslog-ng/include/scl/cee/adapter.conf
%attr(644,root,root) %{_datadir}/syslog-ng/include/scl/discord/discord.conf
%attr(644,root,root) %{_datadir}/syslog-ng/include/scl/fortigate/fortigate.conf
%attr(644,root,root) %{_datadir}/syslog-ng/include/scl/mariadb/audit.conf
%attr(644,root,root) %{_datadir}/syslog-ng/include/scl/python/python-modules.conf
%attr(644,root,root) %{_datadir}/syslog-ng/include/scl/splunk/splunk.conf
%attr(644,root,root) %{_datadir}/syslog-ng/include/scl/logscale/logscale.conf
%attr(644,root,root) %{_datadir}/syslog-ng/include/scl/opensearch/opensearch.conf
%attr(644,root,root) %{_datadir}/syslog-ng/include/scl/google/google-pubsub.conf
%attr(644,root,root) %{_datadir}/syslog-ng/include/scl/openobserve/openobserve.conf
%attr(644,root,root) %{_datadir}/syslog-ng/include/scl/pgsql/pgsql.conf
%attr(644,root,root) %{_datadir}/syslog-ng/include/scl/pihole/pihole.conf
%attr(644,root,root) %{_datadir}/syslog-ng/include/scl/qbittorrent/qbittorrent.conf
%attr(644,root,root) %{_datadir}/syslog-ng/include/scl/darwinosl/darwinosl-metadata-db.csv
%attr(644,root,root) %{_datadir}/syslog-ng/include/scl/darwinosl/plugin.conf
%attr(644,root,root) %{_datadir}/syslog-ng/smart-multi-line.fsm
%attr(644,root,root) %{_datadir}/syslog-ng/xsd/*
%attr(644,root,root) %{_datadir}/syslog-ng/include/scl.conf

%files -n libevtlog-4_6-0
%{_libdir}/libevtlog-*.so.*

%files snmp
%attr(755,root,root) %{_libdir}/syslog-ng/libafsnmp.so

%if %{with curl}
%files curl
%attr(755,root,root) %{_libdir}/syslog-ng/libhttp.so
%dir %{_datadir}/syslog-ng/include/scl/telegram/
%attr(644,root,root) %{_datadir}/syslog-ng/include/scl/telegram/telegram.conf
%dir %{_datadir}/syslog-ng/include/scl/slack/
%attr(644,root,root) %{_datadir}/syslog-ng/include/scl/slack/slack.conf
%dir %{_datadir}/syslog-ng/include/scl/elasticsearch/
%attr(644,root,root) %{_datadir}/syslog-ng/include/scl/elasticsearch/elastic-http.conf

%endif

%if %{with dbi}
%files sql
%dir %{_libdir}/syslog-ng
%attr(755,root,root) %{_libdir}/syslog-ng/libafsql.so

%endif

%if %{with grpc}

%files grpc
%attr(755,root,root) %{_libdir}/libgrpc-protos.*

%files opentelemetry
%attr(755,root,root) %{_libdir}/syslog-ng/libotel.so

%files loki
%attr(755,root,root) %{_libdir}/syslog-ng/libloki.so

%files bigquery
%attr(755,root,root) %{_libdir}/syslog-ng/libbigquery.so

%endif

%if %{with cloudauth}

%files cloudauth
%attr(755,root,root) %{_libdir}/syslog-ng/libcloud_auth.so

%endif

%if %{with bpf}

%files bpf
%attr(755,root,root) %{_libdir}/syslog-ng/libebpf.so

%endif

%files devel
%attr(644,root,root) %{_libdir}/libsyslog-ng.la
%attr(644,root,root) %{_libdir}/libevtlog.la
%attr(644,root,root) %{_libdir}/libsecret-storage.la
%attr(644,root,root) %{_libdir}/libloggen_helper.la
%attr(644,root,root) %{_libdir}/libloggen_plugin.la
%attr(644,root,root) %{_libdir}/syslog-ng/*.la
%attr(755,root,root) %{_libdir}/syslog-ng/loggen/libloggen_socket_plugin.la
%attr(755,root,root) %{_libdir}/syslog-ng/loggen/libloggen_ssl_plugin.la
%{_libdir}/libsyslog-ng.so
%{_libdir}/libevtlog.so
%{_libdir}/libsecret-storage.so
%{_libdir}/libloggen_helper.so
%{_libdir}/libloggen_plugin.so
%attr(644,root,root) %{_libdir}/pkgconfig/syslog-ng.pc
%dir %{_includedir}/syslog-ng
%attr(-,root,root) %{_includedir}/syslog-ng/*
%dir %{_datadir}/syslog-ng/tools
%attr(644,root,root) %{_datadir}/syslog-ng/tools/merge-grammar.py
%attr(644,root,root) %{_datadir}/syslog-ng/tools/cfg-grammar.y
%attr(644,root,root) %{_datadir}/syslog-ng/tools/lex-rules.am
%attr(644,root,root) %{_datadir}/syslog-ng/tools/system-expand.sh

%if %{with python}
%files python
%attr(755,root,root) %{_libdir}/syslog-ng/libmod-python.so
%defattr(-,root,root)
%{_libdir}/syslog-ng/python/syslogng-1.0-py%{py_ver}.egg-info
%dir %{_libdir}/syslog-ng/python
%dir %{_libdir}/syslog-ng/python/syslogng
%{_libdir}/syslog-ng/python/syslogng/*
%dir %{_sysconfdir}/syslog-ng/python/
%{_sysconfdir}/syslog-ng/python/README.md
%{_libdir}/syslog-ng/python/requirements.txt
%exclude %{_libdir}/syslog-ng/python/syslogng/modules/

%files python-modules
%dir %{_libdir}/syslog-ng/python/syslogng/modules/
%{_libdir}/syslog-ng/python/syslogng/modules/*

%endif

%if %{with java}
%files java
%attr(755,root,root) %{_libdir}/syslog-ng/libmod-java.so
%dir %{_libdir}/syslog-ng/java-modules
%attr(755,root,root) %{_libdir}/syslog-ng/java-modules/syslog-ng-core.jar

%endif

%if %{with smtp}
%files smtp
%dir %{_libdir}/syslog-ng
%attr(755,root,root) %{_libdir}/syslog-ng/libafsmtp.so

%endif

%if %{with geoip}
%files geoip
%dir %{_libdir}/syslog-ng
%if 0%{?leap_version} >= 420200
%attr(755,root,root) %{_libdir}/syslog-ng/libgeoip2-plugin.so
%endif
%if 0%{?suse_version} > 1320
%attr(755,root,root) %{_libdir}/syslog-ng/libgeoip2-plugin.so
%endif

%endif

%if %{with redis}
%files redis
%dir %{_libdir}/syslog-ng
%attr(755,root,root) %{_libdir}/syslog-ng/libredis.so

%endif

%if %{with mqtt}

%files mqtt
%defattr(-,root,root)
%dir %{_libdir}/syslog-ng
%attr(755,root,root) %{_libdir}/syslog-ng/libmqtt.so

%endif

%changelog
* Thu Feb  8 2024 peter czanik <peter@czanik.hu>
- fix syslog-ng-devel dependencies (boo#1219672)
* Tue Feb  6 2024 peter czanik <peter@czanik.hu>
- add python3-setuptools as a build requiriement
* Thu Feb  1 2024 peter czanik <peter@czanik.hu>
- update to version 4.6.0
  * BigQuery support
  * CloudAuth support
  * Loki support
  * PubSub support
  * parsers for pgsql, pihole, qbittorrent logs
- move grpc support into separate sub-package
* Mon Sep 18 2023 peter czanik <peter@czanik.hu>
- fix boo#1215386 by removing dependency on var-run.service
  (service is removed in Tumbleweed)
* Mon Jul 31 2023 peter czanik <peter@czanik.hu>
- update to version 4.3.1
  * fixes a crash bug in Python support
  * opensearch destination (SCL)
* Tue Jul 25 2023 peter czanik <peter@czanik.hu>
- update to version 4.3.0
  * OpenTelemetry support
  * BPF support to accelerate UDP source
  * logscale destination
  * scl.conf moved from /etc/syslog-ng
  * use pcre2 instead of pcre
- change BuildRequires from pcre-devel to pcre2-devel
- add BuildRrequires for OpenTelemetry and BPF
* Fri Jul 14 2023 peter czanik <peter@czanik.hu>
- fix Python packaging
* Tue Jun  6 2023 peter czanik <peter@czanik.hu>
- oops, forgot to update the config version string again...
- while there, fixed a config warning about statistics
* Thu Jun  1 2023 peter czanik <peter@czanik.hu>
- update to version 4.2.0
- add Splunk destination to SCL
- plugin rename: dbparser is now called correlation
- new plugin: libmetrics-probe.so
- split Python-based drivers from the Python plugin
* Wed May 24 2023 Jan Engelhardt <jengelh@inai.de>
- Exclude plugins from being turned into RPM dependencies.
* Wed Jan 11 2023 peter czanik <peter@czanik.hu>
- update to 4.0.1
- remove obsolate syslog-ng-nojavah.patch together with
  autotools dependencies
- add dependencies for Python modules
- remove obsolate Obsolates line
- remove Kubernetes config (became a Python module)
* Tue Dec 27 2022 Ludwig Nussel <lnussel@suse.com>
- Replace transitional %%usrmerged macro with regular version check (boo#1206798)
* Tue Aug 16 2022 peter czanik <peter@czanik.hu>
- update to 3.37.1
- add new modules to file lists
- enable MQTT support only for Tumbleweed
* Mon Apr 25 2022 Marcus Meissner <meissner@suse.com>
- URL -> https
* Tue Mar  8 2022 Fridrich Strba <fstrba@suse.com>
- Added patch:
  * syslog-ng-nojavah.patch
    + Do not use the removed javah tool, but the javac's -h option
    + Allows to build with any java-devel >= 1.8
- Require java-devel >= 1.8 for build
- Add build dependency on autoconf and automake since we need them
  to regenerate the build system after we patch it
* Fri Feb 18 2022 peter czanik <peter@czanik.hu>
- disable Java support for ARMv7 (compilation crashes)
* Mon Dec  6 2021 peter czanik <peter@czanik.hu>
- update to 3.35.1
- remove "news" user creation, as it is no more referenced
  from the configuration file
- packaging fixes to remove a few warnings
* Wed Jul 28 2021 peter czanik <peter@czanik.hu>
- update to 3.33.2
- added support for parsing CEE and Fortigate logs
- added Discord destination
- added MQTT destination support
- python3 workdaround removed (commented out for now, fixed upstream)
* Fri Jul 16 2021 Steve Kowalik <steven.kowalik@suse.com>
- Set shebang for merge-grammar.py to be /usr/bin/python3.
* Tue Dec  8 2020 peter czanik <peter@czanik.hu> 3.30.1-0
- update to 3.30.1
- follow up snmp support changes
- add secure logging
- add PAN-OS parser
- add SumoLogic destination
* Thu Nov 26 2020 Ludwig Nussel <lnussel@suse.de>
- prepare usrmerge (boo#1029961)
* Mon May 11 2020 peter czanik <peter@czanik.hu>
- fix bnc#1169385 by removing creating news log files from post,
  adding syslog-ng.conf options to create files/directories
  automatically, and commenting the relevant part out.
* Wed Apr 15 2020 peter czanik <peter@czanik.hu>
- fix libevtlog package name
* Tue Mar 10 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 3.26.1
  * added a new option to multi-line file sources
  * python-http-header: added this new plugin, which makes it possible
    for users to implement HTTP header plugins in Python language
  * azure-auth-header: Added this new plugin, which generates
    authorization header for applications connecting to Azure
  * set-severity(): Added this new rewrite rule for changing message severity.
  * $(list-search): Added a new template function, which returns
    the first index of a pattern in a list.
  * other minor improvements
  * many bug fixes
* Fri Feb 28 2020 Matej Cepl <mcepl@suse.com>
- Fix fixing Python shebang
* Mon Feb  3 2020 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(libsystemd) instead of systemd-devel:
  allow OBS to shortcut through -mini flavors.
* Thu Dec 12 2019 peter czanik <peter@czanik.hu>
- update to 3.25.1
- many bug fixes, improved Redis destination performance
* Wed Nov 27 2019 peter czanik <peter@czanik.hu>
- remove ExcludeArch as bison workaround no more needed
- remove dependency on libgeoip to fix bnc#1156203
  (of course libmaxminddb is still supported)
* Tue Sep  3 2019 peter czanik <peter@czanik.hu>
- updated to 3.23.1 to resolve bnc#1143190
- removed 2482.patch as it was merged upstream
- add wensense & netskope parsers
- add collectd support
- update syslog-ng.conf due to an undocumented include
  syntax used in the config was removed by uspstream
- add SCL to support Elasticsearch destination using
  the http() destination driver
- add SCL to parse junos and checkpoint logs
- changed the location of debuggercli files
- disabled native connector (Rust support)
- "ExcludeArch: i586 s390x" as workaround until bison is fixed
* Fri Apr 12 2019 root <peter@czanik.hu>
- oops, forgot to update version in syslog-ng.conf again...
- moved slack SCL to curl sub-package to silence warning
  on startup
* Wed Jan 30 2019 Dominique Leuenberger <dimstar@opensuse.org>
- Dynamically detect used python3 version.
* Tue Jan  8 2019 peter@czanik.hu
- added 2482.patch to resolve GPL-2.0 vs. BSD-4-Clause
  compatibility problem.
* Fri Dec 21 2018 schwab@suse.de
- Allow building with java 1.8.0.
- Use %%license
* Mon Dec 17 2018 peter@czanik.hu
- updated to 3.19.1
- changed summary again
* Tue Nov 27 2018 Jan Engelhardt <jengelh@inai.de>
- Replace time-sensitive wording of summary.
- Drop %%if..%%endif guards that are idempotent.
- Replace %%__-type macro indirections.
* Mon Nov 12 2018 peter@czanik.hu
- update to 3.18.1
- remove support for SLES11 (sysvinit)
- add support to compile on SLES12+ and Leap 42+
- tons of clean-up
* Thu May 31 2018 peter@czanik.hu
- added network.target to syslog-ng.service
  to resolve bnc#1077975
* Fri Apr  6 2018 peter@czanik.hu
- update to syslog-ng 3.14.1
- remove patch, as merged upstream:
  0001-modules-json-Adaptions-for-json-c-v0.13.patch
- remove patch and revert to jdk 1.7 as 1.9 is problematic:
  syslog-ng-3.10.1-sourcetarget.patch
- add secret-storage, appmodell and SCL files
* Wed Jan 10 2018 Thomas.Blume@suse.com
- fix build error with json-c v0.13 with patch
  0001-modules-json-Adaptions-for-json-c-v0.13.patch
* Tue Jan  9 2018 peter@czanik.hu
- disable Java destination temporarily (it does not build)
* Tue Dec  5 2017 peter@czanik.hu
- fix %%post and mongodb as requested by @idonmez
* Wed Nov 29 2017 peter@czanik.hu
- update to syslog-ng 3.12.1
- add tags parser
- add xml parser
- add Windows eventlog parser
- add syslog-ng-debun + man
- handle evtlog merge (add obsolates, new files, etc.)
- use Python version of merge-grammar
- add libmaxminddb-devel BuildRequires for the geoip2 parser
- add geoip2 parser
- add osquery parser (scl)
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468) (by @RBrownSUSE)
- WARNING:
  disable RabbitMQ and AMQP support as they fail
  to compile with openssl 1.1
  Will be most likely re-enabled in 3.14.1
* Wed Oct 11 2017 jengelh@inai.de
- Update package summaries and RPM group classifications.
  Drop author lists from descriptions. Remove redundant %%clean
  section. Replace old $RPM_ shell vars and make consistent use
  of macros instead.
* Tue Oct 10 2017 fstrba@suse.com
- Do not hardcode dependency on java-1_7_0-openjdk, depend on
  java-devel >= 1.7 instead
- Added patch:
  * syslog-ng-3.10.1-sourcetarget.patch
    + Build Java classes with the lowest required source and target
    levels.
* Wed Jun 21 2017 peter@czanik.hu
- update to version 3.10.1
- update config version
- libcurl.so renamed to libhttp.so
- added module libtfgetent.so
- added module libmap-value-pairs.so
- added module libstardate.so
- added cisco parser (scl)
- added snmptrapd parser files
- add pkgconfig for add-contextual-data
- don't compile curl dest on SLES 11
* Sun Apr  2 2017 meissner@suse.com
- require group and user "news" in new system model.
* Fri Sep  9 2016 peter@czanik.hu
- really update config version to 3.8 (thanks Per for the report)
- move curl (HTTP) support into a subpackage
  to reduce the number of dependencies in the base package
* Tue Aug 23 2016 peter@czanik.hu
- update to 3.8.1
  for a complete list of changes see:
  https://github.com/balabit/syslog-ng/releases/tag/syslog-ng-3.8.1
- add Java support. NOTE:
  no modules due to missing gradle and JAR dependencies
- add curl HTTP support
- disable mongodb for SLES11 (fails to compile)
- update configuration to 3.8
- change datadir parameter (default now includes 'syslog-ng')
- add cef & date modules, apache, loggly, logmatic scl-s
- add disk buffer support
- update java module list
- uncomment Alias=syslog.service in syslog-ng.service
- rename system-expand to system-expand.sh
- add missing: Obsolates: syslog-ng-json (JSON is now in core)
* Wed Jun  1 2016 peter@czanik.hu
- fix bnc#965191 by adding back "Alias=syslog.service" to
  "syslog.service"
- update to 3.7.3, which fixes many small bugs
  https://github.com/balabit/syslog-ng/releases/tag/syslog-ng-3.7.3
- remove obsolate e30fe7c3717a7bda4036448c7777747df1a4e0f9.patch
- using self generated dist tgz, as official tgz is missing
  generated man pages
- fix bnc#982487 by copying config.h manually
* Mon Sep  7 2015 czanik@balabit.hu
- update to syslog-ng 3.7.1
- for a detailed changelog, see upstream at:
  https://github.com/balabit/syslog-ng/releases/tag/syslog-ng-3.7.1
  and
  https://github.com/balabit/syslog-ng/releases/tag/syslog-ng-3.6.1
- FYI: no java support due to lack of gradle
- follow geoip modul name change (tfgeoip -> geoip-plugin)
- add libkvformat.so
- remove notls workaround (openssl is now a hard dependency)
- add python support
- update version in syslog-ng.conf
- move json support to core
- tmp patch to fix compilation on SLES11:
  e30fe7c3717a7bda4036448c7777747df1a4e0f9.patch
- SLES notes: some core dependencies are missing, so you need to
  build in your home repo and have json, libevtlog from Factory
* Wed Mar 25 2015 Led <ledest@gmail.com>
- fix shebang in syslog-ng-service-prepare script that contains
  bash-specific constructions
* Tue Mar  3 2015 dimstar@opensuse.org
- Do not BuildRequire libhiredis0_10: It's responsibility of the
  respective -devel package to pull in the library. On openSUSE <
  13.2.1 (Current Tumbleweed) we keep it to workaround a bug in
  the hiredis-devel package of those releases.
* Fri Aug 22 2014 mt@suse.de
- Stop syslog.socket in %%preun to avoid the daemon we uninstall
  gets started by a log message due to dependencies (bnc#840815).
* Tue Aug  5 2014 pczanik@genesi-usa.com
- update to 3.5.6 (bugfix release)
* Mon Jul 21 2014 czanik@balabit.hu
- update to 3.5.5 (bugfix release)
- copying ivykis headers manually is no more necessary
* Mon May 19 2014 mt@suse.de
- rpm: use _rundir rpm macro if defined (bnc#873857)
* Thu May 15 2014 czanik@balabit.hu
- update to 3.5.4.1
  For a full list of syslog-ng 3.5 related changes, please check
  the upstream changelog at:
  http://www.balabit.com/downloads/files/syslog-ng/open-source-edition/3.5.4.1/changelog-en.txt
- updated config version to 3.5
- added new modules (redis, stomp, etc.)
- use system(); for local logs, which fixes bnc#846762
  https://bugzilla.novell.com/show_bug.cgi?id=846762
- add /etc/syslog-ng/conf.d/ as include dir to config
- added devel package, so external modules can be built
  (like those from the syslog-ng incubator project)
* Fri Jan 24 2014 mt@suse.de
- Added Restart=on-abort to syslog-ng.service (fate#315133)
* Mon Nov  4 2013 czanik@balabit.hu
- update 3.4.5 (bugfix release)
* Thu Oct 24 2013 czanik@balabit.hu
- update 3.4.4 (bugfix release)
* Wed Aug 14 2013 czanik@balabit.hu
- update to 3.4.3 (bugfix release)
* Sun Jun  2 2013 czanik@balabit.hu
- update to 3.4.2, which fixes bnc#815746
  https://bugzilla.novell.com/show_bug.cgi?id=815746
- many bugfixes, including flags(final)
* Sun Apr 14 2013 crrodriguez@opensuse.org
- Fix systemd unit to do only what is required
  by http://www.freedesktop.org/wiki/Software/systemd/syslog
  in particular it should not mess with the ordering of syslog.target
* Mon Mar  4 2013 mt@suse.com
- Fixed to use program() instead of message() to match by program
  names (bnc#805309).
* Fri Feb  8 2013 czanik@balabit.hu
- updated configuration version from 3.3 to 3.4
* Thu Jan 31 2013 czanik@balabit.hu
- update to 3.4.1 release
- bugfixes
* Fri Jan 18 2013 czanik@balabit.hu
- update to 3.4 RC2
- bugfixes
- updates bundled ivykis to 0.36
* Wed Jan  9 2013 mt@suse.com
- Enable syslog-ng.service and create the syslog.service alias link
  in post install -- regardless of a preset config (bnc#790805).
- Check the existence of /etc/init.d/syslog script before calling
  the restart_on_update and stop_on_removal macros to avoid errors
  on update. Since openSUSE 12.3, no syslog init script is shipped
  (bnc#790298,bnc#750478).
* Mon Jan  7 2013 czanik@balabit.hu
- update to 3.4 RC1 (only bugfixes)
- removed temporary syslog-ng-systemd.patch
* Mon Dec 17 2012 czanik@balabit.hu
- update to 3.4 beta1 (only bugfixes)
- added smtp support
- enable features explicitely (add --enable-XXX for
  mongodb and amqp)
- add syslog-ng-systemd.patch temporarilty to fix bug when starting
  from systemd
- enable GeoIP support into separate subpackage
* Fri Dec  7 2012 czanik@balabit.hu
- update to 3.4 git HEAD
- many new features, including:
  - junctions and more complicated log processing paths
  - amqp destination
  - smtp destination
  - json output and parser plugins
  - key rewriting in destination drivers (add, remove prefixes)
  - a number of new template functions (uuid, hash functions, etc)
  - a number of new parsers in db-parser (set, pcre, ...)
  - allow 32 bit message and nvpair sizes
  - improved systemd support
  - demand loaded plugins
  - plugin support for log transport protocols and the network
    driver to be able to use them easily
- add/remove files from pkglist
- added python needed by SLES
* Tue Nov 20 2012 mt@suse.com
- Require syslog-service >= 2.0 on 12.3, otherwise < 2.0, which
  contain the /etc/init.d/syslog init script.
* Mon Nov 12 2012 mt@suse.com
- Fixed build requires / deps to work on 12.x and SLE-11-SP2.
- Initialized SYSLOG_NG_PARAMS env variable in service file.
- Marked additional log sockets file as ghost.
* Mon Nov 12 2012 mt@suse.com
- Added syslog-ng.service and prepare script to spec file sources.
* Fri Nov  9 2012 mt@suse.com
- Changed to provide a specific syslog-ng.service file which
  creates an alias to syslog.service while activation instead
  of using a SYSLOG_DAEMON to choose the syslog daemon.
  A short pre-exec script is used to generate the additional
  (chroot) log socket config (bnc#788330).
- Updated syslog provides/requires and added a conflict with
  otherproviders(syslog).
- Dropped all ifdef-s and cleaned up to specify all relevant
  directories via rpm macros.
- Changed to install in /usr/sbin, compatibility link in /sbin.
* Tue Nov  6 2012 czanik@balabit.hu
- remove ifdef-s related to 11.X support except for systemd
  (so SLES support could be fixed)
- remove no more used parts from spec
- remove syslog-ng.rc-script from sources
* Wed Oct 31 2012 czanik@balabit.hu
- update to 3.3.7 release
- some last minute bugfixes
* Mon Oct  8 2012 czanik@balabit.hu
- update to 3.3.7rc2
- bugfix release
* Wed Aug 29 2012 czanik@balabit.hu
- update to 3.3.6 with many small bugfixes, upstream ivykis
  support, glob support for includes
- systemd patch no more necessary
- less static patch removed, as it was necessary for 11.X
* Thu Jul  5 2012 czanik@balabit.hu
- update to git head
* Tue Apr 17 2012 czanik@balabit.hu
- update to syslog-ng 3.3.5 which fixes even more memleaks
- resolves bnc#757680
* Thu Feb 23 2012 mt@suse.com
- Detect if we have to use the new /run/systemd/journal/syslog
  socket under newer systemd versions, instead of the default
  _PATH_LOG (/dev/log) socket. Avoids update problems and the
  need to adopt config before using init=... boot parameter
  (bnc#747871).
* Fri Jan 27 2012 czanik@balabit.hu
- more changelog, as requested by saschpe
  v3.3.1 was the initial syslog-ng 3.3 release
  fixes and changes, taken from the syslog-ng NEWS file
- Fixes:
  * Fixed set() and subst() rewrite operations to work properly on the
  value() parameter specified in the configuration even if they are
  referenced at multiple spots in the configuration file.  Earlier
  the 2nd and subsequent invocation of the rewrite rule changed
  $MESSAGE.
  * Fixed csv-parser() to work even if it is invoked at multiple spots
  in the configuration file. Earlier, the 2nd and subsequent
  references of the parser rule forgot the list of column names and
  the input template.
  * Fixed the processing of condition() parameter in rewrite rules,
  which was broken if it contained a filter() function call.
  * Fixed program() destination to properly kill the child process on
  reload and shutdown.
  * Fixed a potential division by zero error which could happen for
  large data rates due to a race in an unlocked region.
  * Fixed an assertion failure in mongodb destination that happened
  due to a race condition at high data rates.
  * Fixed an fd leak in the control socket code, that caused the
  control connection file descriptors to be leaked.
  * Fixed a crash problem in the tcp() destination, that occurred at
  or after a reload happens.
  * Fixed a segmentation fault on reload when using the same rewrite
  rule from multiple log paths.
  * Fixed a segmentation fault when processing a reload request in
  case an existing tcp() source is removed from the config and there
  are open connections.
  * Fixed a possible segmentation fault in the scalable queue
  implementation, which happens in case a destination is slower to
  process messages than syslog-ng would like to send them.
  * Fixed a possible file() destination issue that could cause
  syslog-ng to omit data or to write garbage to the log file in case
  the kernel reports that only a smaller portion of the actual write
  request could be accomplished.
  * Fixed an "internal error duplicate config element" error during
  reload due to an invalid bugfix applied for 3.3.1.  Older beta
  versions of 3.3 were not affected.
  * Fixed a memory leak that causes macro based file destinations to
  leak their queue when destination files are closed due to
  time-reap().
  * Fixed the handling of the condition() option for rewrite rules.
  * Fixed a race condition in value-pairs support, potentially causing
  heap corruption problems when $(format-json) is used in threaded
  mode.
  * Fixed a memory leak in value-pairs template function argument
  parsing, fixing a leak if $(format-json) is used.
  * Repeated definitions of source, destination, filter, rewrite,
  parser and block elements are not allowed by default anymore.
  These are reported as configuration errors unless
    @define allow-config-dups 1
  is specified in the configuration file.
  * Fixed pdbtool error reporting in "pdbtool test" to make it easier
  to understand what went wrong.
  * Added an SQL connection health check in case an INSERT failed.
  This way syslog-ng handles SQL server timeouts better.
  * Fixed support for systemd socket activation. Previously such
  sockets were not set to non-blocking mode, causing syslog-ng to
  hang.
  * Fixed the filter() function in the filter expression to work also
  when used as a part of an AND or OR construct.
  * Allow the sql() destination to operate even without an indexes()
  option. That parameter was meant to be optional, but it wasn't.
  * Fixed compilation issues if no OpenSSL is present.
  * Fixed a minor memory leak in the usertty() driver that can increase
  memory usage on every reload. (The username() parameter wasn't
  properly freed on reload).
  * Fixed a minor memory leak in the sql() driver that can increase
  the memory usage on every reload (indexes() parameter wasn't
  properly freed on reload).
- Changes
  * db-parser() automatically sets a tag named '.classifier.unknown'
  if the message doesn't match.
  * The use of actions in db-parser() for messages without a
  correllation context was inconsistently indexing messages. For
  actions in rules that had correllation @0 was the new message
  being generated, and @1 was the message that triggered the rule.
  Without correllation @0 was used for the triggering message, which
  is greatly inconsistent and unintuitive.  This was fixed by
  changing the behaviour for rules without correllation, now both
  correllation and non-correllation rules use @0 for the new
  message, and @1 for the triggering message.  This is an
  incompatible change in the db-parser() format.
  * The value of the $TAGS macro is added to pdbtool match output.
  * unix-dgram() and unix-stream() error logging on systemd failures
  became more detailed for easier troubleshooting.
* Thu Jan 26 2012 czanik@balabit.hu
- fix systemd support for openSUSE > 12.1
* Fri Jan 20 2012 czanik@balabit.hu
- update to 3.3.4
* Wed Jan 11 2012 czanik@balabit.hu
- update to the latest 3.3-git
* Tue Jan  3 2012 czanik@balabit.hu
- update to 3.3.3
- remove filter patch
- fix afsql related warning
* Tue Dec 20 2011 coolo@suse.com
- remove call to suse_update_config (very old work around)
* Tue Oct 25 2011 czanik@balabit.hu
- add patch for filters bug
  https://bugzilla.balabit.com/show_bug.cgi?id=140
  so firewall logs are correctly filtered
* Mon Oct  3 2011 czanik@balabit.hu
- update to 3.3.1 (3.3 final) which fixes some more minor
  problems and updates NEWS
* Thu Sep 29 2011 czanik@balabit.hu
- updated to latest git, which made time patch redundant
  and also fixes for mongodb, memory leaks, etc.
- fix 11.3 packaging
- enable json support also for 11.4
* Fri Sep 23 2011 czanik@balabit.hu
- updated to latest git snapshot including fix for bnc#719102
- enabled capabilities support >11.4 only
- moved libafmongodb to /usr
- added fix for compiledate
- changed time patch to configure option
  (which does not work yet...)
- removed patches previously picked from git
* Mon Sep  5 2011 czanik@balabit.hu
- fix for an ugly BSD date problem: when using original dates
  in September - December, all turn up as from December
  patch to be removed on next release
* Wed Aug 24 2011 mt@suse.de
- Adopted to require new syslog-service package on 12.x, that
  provides the /etc/init.d/syslog LSB init script and systemd
  syslog.service service file. Removed syslog-ng.service file
  installation from spec file. (fate#311316).
* Thu Aug 18 2011 czanik@balabit.hu
- updated to syslog-ng-3.3.0beta2, a new major release with many
  new features:
  * full multi threading
  * mongodb and json output support
  * new default port numbers for syslog()
  For complete list, please read NEWS file provided in the package.
- removed some unnecessary docs (INSTALL, etc.)
- updated config and enabled multi threading by default
- added json subpackage
- keep only libafsocket.so (the notls version is not used)
* Mon Jun  6 2011 mt@suse.de
- Updated to syslog-ng-3.2.4, maintenance release fixing several
  issues -- a digest of the changes:
  * A bug was found in the pcre implementation for subst(). If the
    "global" flag is specified and pcre returns an error, an infinite
    loop is created, consuming memory in the process. It is triggered
    by PCRE 8.12, but could potentially affect older versions too.
    (bnc#697374, CVE-2011-1951)
  * Fixed a potential use of uninitialized memory in the configuration
    file parser, no bug was triggered but gcc 4.6 reported it via a
    warning.
  * Fixed a possible security issue on Debian/kFreeBSD and on platforms
    where mode_t is an unsigned 16 bit value (FreeBSD,HP-UX).
    (CVE-2011-0343)
  * Fixes an y2k38 problem that causes syslog-ng to use 100%% CPU time
    in case mark messages are enabled and the UNIX timestamps overflows
    a signed 32 bit counter, which happens in 19th, January 2038.
  * Fixed file() destination to work on device nodes (e.g. files in
    /dev).  Without this change, syslog-ng started using 100%% CPU time
    if given devices as destinations that couldn't always consume data.
  * Don't attempt to remember the current file position for source
    files that are read with follow-freq(0), e.g. /dev/klog and /proc/kmsg.
  * Added systemd socket activation support.
  For complete list, please read NEWS file provided in the package.
- Removed obsolete systemd integration patch, added to install syslog-ng
  service file as forced in bnc#696963 even feature 311316 is not yet
  implemented, that is, log rotation files do not work, chroot socket
  config file is never generated when running under systemd.
- Enabled to read kernel messages directly (/proc/kmsg) for 12.x
- Added generation of dummy additional-log-sockets.conf in post install
- Adopted less static patch to build on 11.3.
* Fri May 27 2011 mt@suse.de
- Removed touch of obsolete /var/log/boot.log from spec post.
* Thu Feb 10 2011 mt@suse.de
- Fixed typo module-path in the config file (bnc#664931#c5).
* Wed Feb  2 2011 mt@suse.de
- Moved sql support lib into separate syslog-ng-sql package,
  adopted the module-path patch and disabled loading of the
  sql module in scl/modules.conf config file by default.
  Adopted spec file to use with_sql for conditional build.
* Wed Feb  2 2011 czanik@balabit.hu
- added module-path patch to be able to load modules
  also from /usr and removes an ugly warning message
* Tue Feb  1 2011 mt@suse.de
- Merged all the systemd integration steps patches into one.
* Tue Feb  1 2011 czanik@balabit.hu
- added systemd patches from algernon@balabit.hu
* Fri Jan 28 2011 czanik@balabit.hu
- add database (libdbi) support for 11.4 and up
- use systemd patches only on 11.4 and up
* Tue Jan 18 2011 mt@suse.de
- Updated systemd support to the patch set sent upstream and
  additional workaround to not break the syslog-ng.ctl sock.
  Current limitation is, that *all* unix sockets have to be
  set up same way, that is either systemd activated or not,
  because the systemd patch disables unlink&bind functions.
* Tue Jan 18 2011 czanik@balabit.hu
- temporarily disabled systemd support
- update to 3.2.2 bugfix release
* Fri Dec 10 2010 mt@suse.de
- Implemented a first version of systemd socket activation support
- Enabled suppress config option to catch log message dupplicates
  in case a program runs amok until disk is full (bnc#656197).
- Disabled build date/time in binary to avoid rebuild (rpmlint).
- Do not install /lib*/libsyslog-ng.so devel file (rpmlint).
* Tue Nov 30 2010 czanik@balabit.hu
- update to 3.2.1 release
- libdbi support is added but commented out (libdbi not yet in
  factory)
- many little fixes (added man pages, new config files, etc.)
- the new system() from upstream not yet used because of AppArmor
* Sun Nov 21 2010 coolo@novell.com
- build against the dynamic glib in /lib on 11.4 to fix build
* Sun Nov 21 2010 coolo@novell.com
- build against libnet-devel on 11.4
* Thu Aug  5 2010 pczanik@fang.fa.gau.hu
- update to version 3.1.2, which makes most of the patches
  redundant
* Tue Jun  8 2010 pczanik@fang.fa.gau.hu
- an upstream modified version of the old SuSE patch:
  syslog-ng-avoid-getpwgrnam_-1.dif
* Wed Jun  2 2010 pczanik@fang.fa.gau.hu
- some more patches accepted by upstream: bnc#568150
* Tue May  4 2010 pczanik@fang.fa.gau.hu
- removed /var/tmp/syslog-ng from rpm to prepare for
  https://features.opensuse.org/303793
- upstream accepted some patches from the 2.0.9 openSUSE
  package, applied now, as 3.1.2 is still far away
* Tue Apr 13 2010 mt@suse.de
- Reformated last changes entry to avoid overlong lines,
  added reason why some of the features are disabled.
* Tue Apr 13 2010 pczanik@fang.fa.gau.hu
- upgraded to version 3.1.1
- removed patches, which were made redundant by 3.1.1
- enabled pcre, modified the 'less-static' patch
- NEWS from 2.0 to 3.0
  * Version 3.0 of syslog-ng supports the new syslog protocol
    standards by the Internet Engineering Task Force (IETF).
  * Log statements can be embedded into each other, making it
    possible to design complex log paths. That way for example
    the results of a filter can be sent to multiple destinations,
    or it can be sent to a destination unchanged, and partly
    rewritten for the other destination.
  * The encoding of source files can be set for proper character
    conversion (internally syslog-ng represents every message in
    UTF-8).
  * The syslog-ng application assigns a unique message
    identification number to every log message, making it easy
    to detect if any messages are lost.
  * The syslog-ng application can read, process, and rewrite
    structured messages (e.g., Apache webserver logs) using
    templates and regular expressions. Both messages with fixed
    field sizes and fields separated with delimiters (e.g.,
    comma-separated values) are supported.
- NEWS from 3.0 to 3.1
  * Support for patterndb v2 and v3 format, along with a bunch
    to new parsers: ANYSTRING, IPv6, IPvANY and FLOAT.
  * Added a new "pdbtool" utility to manage patterndb files:
    convert them from v1 or v2 format, merge mulitple patterndb
    files into one and look up matching patterns given a specific
    message.
  * Support for message tags: tags can be assigned to log messages
    as they enter syslog-ng: either by the source driver or via
    patterndb.
    Later it these tags can be used for efficient filtering.
  * Added support for rewriting structured data.
  * Macros and name-value pairs got a little tighter integration,
    in filters where syslog-ng 3.0 was limited to only use
    name-value pairs, with 3.1 you can also use macros.
  * Enhanced dynamic name-value performance by a factor of three.
  * Some parsers got additional features: NUMBER is now able to
    parse hexadecimal numbers, ESTRING is now able to search for
    multiple characters as the end of the string.
  * Added non-standard and non-portable facility codes (range
    10-15), decouple syslog-ng facility name information from
    the system used to compile syslog-ng on.
- new features, which are not enabled because of /usr dependency:
  * TLS support
  * logging to databases
* Wed Mar 31 2010 pczanik@fang.fa.gau.hu
- added two temporary patches to fix pipe() problems
- added include "/var/run/syslog-ng/additional-log-sockets.conf";
  to syslog-ng.conf to replace the old "-a" mechanism
* Wed Mar 24 2010 pczanik@fang.fa.gau.hu
- updated to 3.1.0 release
- added some new utilities (pdbtool & syslog-ng-ctl)
- removed most of the patches to stay as close to upstream
  as possible
- patch to compile only glib statically
- updated syslog-ng.conf to v3.0 syntax
* Mon Jan 18 2010 mt@suse.de
- Fixed to inform user instead to fail when the removed summary()
  suse extension option were used in old config (bnc#519653).
* Fri Jan 15 2010 mt@suse.de
- Applied POLLERR handling fixes for logreader/logwriter causing
  100%% CPU usage e.g. when a UDP destination is down (bnc#541802).
* Wed Feb  4 2009 crrodriguez@suse.de
- use shared libevtlog and libwrap that are available in /%%{_lib}
  still uses static glib2.
* Mon Dec  1 2008 mt@suse.de
- Fixed MARK message function to use local timezone (bnc#450174).
* Tue Nov 18 2008 mt@suse.de
- Fixed chroot / chdir usage (CVE-2008-5110, bnc#445912).
* Wed Sep 10 2008 mt@suse.de
- Added a patch to link libnet dynamically; the static libnet is
  dropped from the package, the dynamic lib moved to /%%_lib now.
* Wed Sep  3 2008 mt@suse.de
- Moved /etc/logrotate.d/syslog-ng content to klogd (in syslogd
  source) package, that provides the /etc/init.d/syslog script.
* Wed Sep  3 2008 mt@suse.de
- Added patch to avoid getpwnam/getgrnam calls with on negative
  values, e.g. on -1 to skip file chown/grp/mod. This calls has
  caused an ldap search request on systems using nss_ldap and if
  the ldap server was running on the same machine and tryed to
  log, a deadlock happened (bnc#414955).
- Applied a backported patch allowing to disable permission and
  ownership changes on existing files, when the owner/group/perm
  option in the file/pipe destination definition is set to -1.
* Fri Aug 22 2008 aj@suse.de
- Fix fillup call.
* Mon Jul 14 2008 mt@suse.de
- Moved build of the eventlog-0.2.7 lib into separate spec file.
* Wed Apr 30 2008 mt@suse.de
- Update to syslog-ng 2.0.9 (fate#303216).
- Disabled -fPIE/-pie usage, that is not possible any more.
- Changed the configure path usage in syslog-ng.h to point to
  the desired installation paths.
- Increased level of successfull reload message to notice.
- Disabled parsing of a hostname on afunix (/dev/log) sockets
  as workaround to not to interpret first part of a broken tag
  containing spaces as hostname; the glibc syslog functions do
  not send any hostname (bnc#49521).
- Reimplemented patch to update own hostname on SIGHUP/reload
  (bnc#116466).
- Reimplemented -a <log socket> feature (fate#300891).
- Mentioned /usr/share/doc/packages/syslog-ng as documentation
  source in manual pages (bnc#373960).
* Wed Mar 26 2008 mt@suse.de
- Documented -a option in syslog-ng.8 manual page, improved
  sentence about usage without root permissions (bnc#358249).
* Wed Oct 31 2007 mt@suse.de
- Bug #334537: Fixes for acpid filter in syslog-ng.conf
* Mon Jul 30 2007 mt@suse.de
- Feature #302032: Improved patch adding a global summary(secs)
  option allowing to specify the summary generation frequency
  or disable it by setting summary(0).
  Modified patch file: syslog-ng-summarize.dif
* Tue Jul 24 2007 mt@suse.de
- Applied a patch allowing to disable permission and ownership
  changes on existing files, when the owner/group/perm option
  in the file/pipe destination definition is set to -1.
  New patch file: syslog-ng-no-perm-change.dif
- Improved acpid null destination in default config to avoid
  /dev/null use at all.
* Tue Jul 24 2007 coolo@suse.de
- perm(-1) for /dev/null results in a 640 - which breaks almost
  anything else in the system
* Fri Jul 20 2007 mt@suse.de
- Feature #302032: summarize repeated log messages
- Improved new null destination declaration to use
  pipe driver and not to change any permissions
- Improved class comparization in filter-checks
* Wed Jul 11 2007 seife@suse.de
- Fix the acpid logging rules (the messages that should have been
  dropped ended up in /var/log/messages).
* Tue Jul 10 2007 seife@suse.de
- Adopt to the new acpid logging prefix and make acpid logs less
  verbose by default (Bug #290398).
* Wed Jun  6 2007 mt@suse.de
- Bug #278741: Fixed to use /dev/console instead of /dev/tty10
  on s390(x) in the console destination.
- Removed aaa_base from PreReq (run_suseconfig macro not
  used any more), added /etc/init.d/syslog to PreReq.
* Wed May 30 2007 mt@suse.de
- Updated to syslog-ng-1.6.12, fixing negation for the netmask()
  filter, increasing hostname buffers to 256 characters, adding
  so_rcvbuf option to adjust the afinet receive buffer, forcing
  log_fifo_size to an minimum of 1000 elements
- Adopted update_own_hostname and afunix_dest_reconnect patches
- Bug #257101: Fix to log parse errors while reload (SIGHUP).
  New patch file: syslog-ng-verbose_reload.dif
- Fixed console destination in default config to use pipe driver,
  disabled permission and ownerships for console and xconsole.
* Mon May 14 2007 mt@suse.de
- Bug #256671: Added reset of the sysconfig SYSLOG_DAEMON
  variable to "" (autodetect daemon) in rpm postun script.
* Thu Mar 29 2007 ro@suse.de
- added klogd to BuildRequires
* Thu Mar 29 2007 rguenther@suse.de
- Add flex BuildRequires.
* Sat Mar  3 2007 mt@suse.de
- Bug #250562: Fixed to set signal handlers before the config
  and thus the log destinations are initialized to avoid the
  creation of zombie processes when a program (e.g. destination)
  fails to execute, e.g. because apparmor profile prohibits it.
  Changed to use sigaction() instead of the signal() function.
  New patch file: syslog-ng-sigaction.dif
- Cleaned up the syslog-ng-filter_checks patch (fix for #240676).
- Added remote logserver destination example to the config file.
- Moved the allmessages example to the begin to catch all msgs.
* Thu Mar  1 2007 mt@suse.de
- Bug #249555: Fix for additional log sockets extension; syslog-ng
  dropped messages on the sockets after a config file reload.
  Fixed patch file: syslog-ng-additional-log-sockets.dif
* Wed Feb 28 2007 mt@suse.de
- Bug #240676: Implemented checks to detect recursive filter
  definitions. New patch file: syslog-ng-filter_checks.dif
* Tue Nov 14 2006 schwab@suse.de
- Fix crash in handle_*_line.
* Wed Sep 13 2006 mt@suse.de
- Feature #300891: Remove SuSEconfig dependency of syslog-ng
  * Implemented an extension allowing to pass additional log
    sockets using -a options.
  * Documented it in the README.SuSE file and in the default
    configuration file.
  * Removed SuSEconfig.syslog-ng and it's syslog-ng.conf.in
    and adopted the RPM spec file.
  New patch file: syslog-ng-additional-log-sockets.dif
* Fri Sep  1 2006 mt@suse.de
- Updated to syslog-ng-1.6.11, providing bugfixes for timezone
  calculations, false messages about permission changes, a
  workaround for lose of one message when connection is broken
  as well as some scalability improvements tunable using the
  time_sleep() global option.
* Mon May 29 2006 mt@suse.de
- Bug #177961: Added patch to avoid startup failure in case
  the initial connect to a unix socket destination fails.
  Instead, reinit the driver after time_reopen secs (option).
  New patch file: syslog-ng-afunix_dest_reconnect.dif
* Mon Apr 10 2006 mt@suse.de
- Bug #150052: added aaa_base to RPM PreReq to avoid failure
  of the run_suseconfig macro when yast2 directory installer
  is used (YAST_IS_RUNNING variable isn't set to "instsys").
* Wed Feb 15 2006 mt@suse.de
- Bug #147748: Added NetworkManager logging rule
- Added /etc/logrotate.d/syslog-ng file providing
  log rotation config for acpid and NetworkManager
- Fixed owner/group inconsistence for news.* files
- Fixed destination for news.notice messages
- Merged syslog-ng.conf.in and syslog-ng.conf.default
* Thu Feb  9 2006 mt@suse.de
- Bug #116466: update cached hostname on SIGHUP (reload)
  New patch file: syslog-ng-update_own_hostname.dif
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Dec 20 2005 ro@suse.de
- remove explicit requires for devs
* Fri Dec  9 2005 seife@suse.de
- add acpid logging rule
* Thu Nov 10 2005 schwab@suse.de
- Don't strip binaries.
* Mon Jul 25 2005 aj@suse.de
- Resubmit with fixed changes file.
* Mon Jul 25 2005 mt@suse.de
- Updated to syslog-ng-1.6.8
- Bug# 98232: added installing of a default config file
  that will be overwritten by SuSEconfig if configured
* Thu Jun 23 2005 ro@suse.de
- build with fPIC/pie
* Fri Apr 29 2005 mt@suse.de
- Added gperf to neededforbuild
* Tue Mar 15 2005 mt@suse.de
- call run_suseconfig macro in rpm post for suse_version > 9.0
  instead a manual SuSEconfig --module syslog-ng
* Thu Mar 10 2005 mt@suse.de
- increased interval for logging of stats messages to 1 hour
* Tue Mar  8 2005 mt@suse.de
- Bug #71264: added stop_on_removal/restart_on_removal
  to the spec file
* Fri Feb 11 2005 mt@suse.de
- fixed rpm post-install script to fillup syslog variables
  provided by klogd package as well
- fixed rpm post-install script to switch SYSLOG_DAEMON to
  ourself if it is set to a daemon that is not installed
  (happens if klogd+syslog-ng are installed on fresh system)
- added klogd to neededforbuild
* Fri Feb 11 2005 mt@suse.de
- require and use klogd instead of syslogd
- provides "syslog"
* Thu Jan 27 2005 mt@suse.de
- Feature ID 100044: log firewall (iptables) messages into
  /var/log/firewall and filter them out for messages, warn
  and console destinations.
- Changed config file to better match current syslog.conf:
  changed default permissions from 0600 to 0640,
  added logging into /var/log/mail.{info,warn,err},
  enabled fsync option for /var/log/{warn,mail.err}
* Wed Jan 12 2005 mt@suse.de
- Applied fixes from 1.6.5+20050112 snapshot (see ChangeLog)
  New patch file: syslog-ng-1.6.5+20050112.dif
* Wed Jan 12 2005 mt@suse.de
- Bug #49521: workaround to not to interpret tags containing
  spaces as hostname on afunix ($root/dev/log) sources, since
  the syslog(3) function does not send any hostname.
  Old behaviour can be restored using the bad_hostname option
  explicitly set to its default value "^$".
  New patch file: syslog-ng-afunix_no_hostname.dif
* Tue Aug 31 2004 mt@suse.de
- updated to version 1.6.5
- bug #44364, removed obsolete notify message
* Thu Jul 22 2004 mt@suse.de
- updated to version 1.6.4
* Wed Feb 11 2004 mt@suse.de
- updated to version 1.6.2
* Sun Jan 11 2004 adrian@suse.de
- build as user
* Wed Sep  3 2003 mt@suse.de
- changed to use absolute path to rcsyslog in SuSEconfig.syslog-ng
- changed to call SuSEconfig --module syslog-ng in spec
* Tue Aug 26 2003 mt@suse.de
- added yast2 sysconfig metadata Config and ServiceRestart.
- updated to actual stable version 1.6.0rc3
* Fri Jan 31 2003 mt@suse.de
- removed sysconfig metadata paths - syslogd provides them
- added syslogd to PreReq to make sure, it is installed first
* Thu Jan 23 2003 mt@suse.de
- updated to 1.4.17 containing macro expansion fixes;
  removed patch: syslog-ng-macro_expansion_length.dif
- added patch fixing exit status returned to the shell
  on daemon initialization failures after fork is done
  new patch file: syslog-ng-daemon_init.dif
- no init-script provided any more, except of a sample
  script for the removed SYSLOG_NG_REPLACE=no feature
- SYSLOG_NG_* variables are in /etc/sysconfig/syslog now
- syslog package will provide the needed init-script;
  syslog-ng now requires sysklogd and syslog (service)
- added SuSEconfig.syslog-ng with support for additional
  log sockets (SYSLOGD_ADDITIONAL_SOCKET*) and added a
  SYSLOG_NG_CREATE_CONFIG="yes" for enabling/disabling
* Fri Oct 18 2002 mt@suse.de
- changed to use a pre-build syslog-ng.pdf file
- applied patch for length check in macro expansion,
  done by krahmer@suse.de
  new patch file: syslog-ng-macro_expansion_length.dif
* Mon Oct 14 2002 mt@suse.de
- updated to syslog-ng-1.4.16 -- includes security fix for
  buffer overflow in macro expansion template handling
  see http://www.balabit.hu/static/zsa/ZSA-2002-014-en.txt
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Tue Sep 10 2002 olh@suse.de
- provides syslog for hotplug
* Mon Aug 19 2002 mmj@suse.de
- Correct PreReq
* Sun Aug 18 2002 ro@suse.de
- added ghostscript-x11-packages to neededforbuild (for gs)
* Fri Mar  1 2002 mt@suse.de
- fixed /dev/log source type to unix-dgram (Bugzilla #13156)
* Tue Feb 26 2002 mt@suse.de
- fixed udp-source example definition
- added a start-check for to catch exit code on temporary failures
* Thu Jan 31 2002 ro@suse.de
- changed neededforbuild <libpng> to <libpng-devel-packages>
* Thu Jan 31 2002 ro@suse.de
- added libgimpprint to neededforbuild
* Tue Jan 15 2002 egmont@suselinux.hu
- removed colons from startup/shutdown messages
* Mon Jan 14 2002 ro@suse.de
- removed START_SYSLOG_NG
- rest of variables to /etc/sysconfig/syslog-ng
* Wed Oct 31 2001 mt@suse.de
- updated to 1.4.14 - fixes a problem causing opened unix domain
  sessions to drop during SIGHUP
* Fri Jul 20 2001 mt@suse.de
- updated to 1.4.12
- fixed run level script to be LSB compliant
- added glib and gppshare to neededforbuild (ghostscript deps)
- added gs -> gs_serv link if not there
* Fri Jul 20 2001 kukuk@suse.de
- changed neededforbuild <gs_fonts> to <ghostscript-fonts-std>
- changed neededforbuild <gs_lib> to <ghostscript-library>
- changed neededforbuild <gs_serv> to <ghostscript-serv>
* Thu May  3 2001 mt@suse.de
- added suse_update_config macro in spec
* Thu Apr 26 2001 mt@suse.de
- changed runlevel script
* Tue Mar 20 2001 ro@suse.de
- create dir before installing file into it
* Thu Mar 15 2001 mt@suse.de
- new package, version 1.4.11
